==> pymol_1.0.orig.tar.gz: pymol-1.0/layer0/os_proprietary.h <==
/* 
A* -------------------------------------------------------------------
B* This file contains source code for the PyMOL computer program
C* copyright 1998-2000 by Warren Lyford Delano of DeLano Scientific. 
D* -------------------------------------------------------------------
E* It is unlawful to modify or remove this copyright notice.
F* -------------------------------------------------------------------
G* Please see the accompanying LICENSE file for further information. 
H* -------------------------------------------------------------------
I* Additional authors of this source file include:
-* 
-* 
-*
Z* -------------------------------------------------------------------
*/
#ifndef _H_os_proprietary

#include "os_predef.h"

/* PROPRIETARY CODE SEGMENT DISCLAIMER:
 *
 * DeLano Scientific LLC supports and strongly encourages compilation
 * of open-source PyMOL source code on open-source operating systems
 * with open-source development tools (e.g. Linux/XFree86 with GCC
 * using Python's distutils or perhaps the GNU Build System).
 *
 * We do not support, but nor do we necessarily preclude, compilation
 * of open-source PyMOL source code on proprietary operating systems
 * such as Microsoft Windows using proprietary development tools such
 * as Microsoft Visual Studio.  Such activities are simply beyond the
 * scope of the PyMOL Open-Source Project as we choose to define it.
 *
 * Please note that we generally view compilation of PyMOL source code
 * on proprietary platforms as the obvious and logical foundation for
 * productive business relationships with defined and mutual benefits.
 * In other words, if you depend on PyMOL to run well on proprietary
 * operating systems, then it is in your interest to engage our
 * business on business-like terms, such as through paid software
 * subscriptions and licenses, through software development
 * partnerships, or by participating in collaborations and joint
 * ventures. 
 *
 * If, however, you still feel that you absolutely must compile
 * open-source PyMOL source code on proprietary operating systems,
 * then we suggest use of Linux-like tools and environments, such as
 * Red Hat's Cygwin on Windows and X11/GCC/Fink on Mac OS X, since
 * those tools will provide the greatest compatibility and synergy
 * with the Open-Source PyMOL project.  Regardless of the approach you
 * choose, usage of and reliance upon marked proprietary code segments
 * should be avoided wherever and whenever possible.
 *
 * THE FOLLOWING CODE SEGMENT AND ALL OTHERS MARKED "PROPRIETARY" ARE
 * PROVIDED AS IS AND FOR USE AT YOUR OWN RISK WITH NO ASSURANCES OF
 * FUTURE FUNCTION OR AVAILABILITY.  WE STRONGLY CAUTION THAT YOU DO
 * NOT RELY UPON PROPRIETARY CODE SEGMENTS SINCE THEY MAY BE ALTERED
 * OR REMOVED AT ANY TIME AND WITHOUT NOTICE OF ANY KIND.  WARREN
 * LYFORD DELANO AND DELANO SCIENTIFIC LLC DISCLAIM ALL WARRANTIES
 * WITH REGARD TO PROPRIETARY CODE SEGMENTS, INCLUDING ALL IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS.  IN NO EVENT SHALL
 * WARREN LYFORD DELANO OR DELANO SCIENTIFIC LLC BE LIABLE FOR ANY
 * SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
 * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
 * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF PROPRIETARY
 * CODE SEGMENTS.
 */

/* BEGIN PROPRIETARY CODE SEGMENT */
#ifdef WIN32
#include<windows.h> 
#endif
/* END PROPRIETARY CODE SEGMENT */

#endif

==> pymol_1.2r2.orig.tar.gz: pymol-1.2r2/layer0/os_proprietary.h <==


/* 
A* -------------------------------------------------------------------
B* This file contains source code for the PyMOL computer program
C* copyright 1998-2000 by Warren Lyford Delano of DeLano Scientific. 
D* -------------------------------------------------------------------
E* It is unlawful to modify or remove this copyright notice.
F* -------------------------------------------------------------------
G* Please see the accompanying LICENSE file for further information. 
H* -------------------------------------------------------------------
I* Additional authors of this source file include:
-* 
-* 
-*
Z* -------------------------------------------------------------------
*/
#ifndef _H_os_proprietary

#include "os_predef.h"


/* PROPRIETARY CODE SEGMENT DISCLAIMER:
 *
 * DeLano Scientific LLC supports and encourages compilation of
 * open-source PyMOL source code on open-source operating systems
 * using open-source development tools (e.g. Linux/X11 using GCC and
 * either Python's distutils or the GNU Build System).
 *
 * We do not support, but nor do we necessarily preclude, compilation
 * of open-source PyMOL source code on proprietary operating systems
 * such as Microsoft Windows or Mac OS X, using proprietary
 * development tools like Microsoft Visual Studio or Apple's Xcode.
 * Such activities are merely beyond the scope of the PyMOL
 * Open-Source Project as we choose to define it.
 *
 * Please note that we generally view compilation of PyMOL source code
 * on proprietary platforms as the appropriate logical foundation for
 * productive business relationships with defined mutual benefits.  In
 * other words, if you depend on PyMOL to run well on proprietary
 * operating systems in your profession or business, then it is likely
 * in your interest to gain access to our proprietary builds by
 * engaging DeLano Scientific LLC on business-like terms, such as
 * through paid software subscriptions and licenses, through software
 * development partnerships, or by participating in one or more of our
 * consortium projects.
 *
 * If, however, you still feel that you absolutely must compile
 * open-source PyMOL source code on proprietary operating systems,
 * then we suggest use of Linux-like tools and environments, such as
 * Red Hat's Cygwin on Windows and X11/GCC/Fink on Mac OS X, since
 * those tools will provide the greatest compatibility and synergy
 * with the Open-Source PyMOL project.  Regardless of the approach you
 * choose, usage of and reliance upon marked proprietary code segments
 * should be avoided wherever and whenever possible.
 *
 * THE FOLLOWING CODE SEGMENT AND ALL OTHERS MARKED "PROPRIETARY" ARE
 * PROVIDED AS IS AND FOR USE AT YOUR OWN RISK WITH NO ASSURANCES OF
 * FUTURE FUNCTION OR AVAILABILITY.  WE STRONGLY CAUTION THAT YOU DO
 * NOT RELY UPON PROPRIETARY CODE SEGMENTS SINCE THEY MAY BE ALTERED
 * OR REMOVED AT ANY TIME AND WITHOUT NOTICE OF ANY KIND.  WARREN
 * LYFORD DELANO AND DELANO SCIENTIFIC LLC DISCLAIM ALL WARRANTIES
 * WITH REGARD TO PROPRIETARY CODE SEGMENTS, INCLUDING ALL IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS.  IN NO EVENT SHALL
 * WARREN LYFORD DELANO OR DELANO SCIENTIFIC LLC BE LIABLE FOR ANY
 * SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
 * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
 * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF PROPRIETARY
 * CODE SEGMENTS.
 */


/* BEGIN PROPRIETARY CODE SEGMENT */
#ifdef WIN32
#include<windows.h>
#endif


/* END PROPRIETARY CODE SEGMENT */

#endif
